@@ -1,4 +1,5 @@
 import configparser
+import logging
 import os
 import typing
 
@@ -8,21 +9,12 @@ import neosctl
 from neosctl import (
     auth,
     constant,
-    consume,
-    iam,
-    kafka,
-    metadata,
-    product,
     profile,
-    registry,
     schema,
-    secret,
-    source,
-    spark,
-    storage,
+    services,
     util,
 )
-from neosctl.util import get_user_profile, read_config_dotfile
+from neosctl.util import get_user_profile, read_config_dotfile, read_credential_dotfile, user_profile_callback
 
 
 def _generate_common_schema(
@@ -32,6 +24,7 @@ def _generate_common_schema(
     storage_api_url: str,
     profile_name: str,
     config: configparser.ConfigParser,
+    credential: configparser.ConfigParser,
     profile: typing.Union[schema.Profile, schema.OptionalProfile, None] = None,
 ) -> schema.Common:
     """Generate a common schema object.
@@ -45,6 +38,7 @@ def _generate_common_schema(
         storage_api_url=storage_api_url,
         profile_name=profile_name,
         config=config,
+        credential=credential,
         profile=profile,
     )
     common_schema.gateway_api_url = common_schema.get_gateway_api_url()
@@ -105,8 +99,19 @@ def _callback(
     Allow missing user_profile to support profile generation etc.
     """
     config = read_config_dotfile()
+    credential = read_credential_dotfile()
     user_profile = get_user_profile(config, profile, allow_missing=True)
 
+    logger = logging.getLogger("neosctl.error")
+    logger.setLevel(logging.INFO)
+    formatter = logging.Formatter("%(asctime)s | %(levelname)s | %(message)s")
+
+    file_handler = logging.FileHandler(constant.LOG_FILEPATH)
+    file_handler.setLevel(logging.INFO)
+    file_handler.setFormatter(formatter)
+
+    logger.addHandler(file_handler)
+
     common_schema = _generate_common_schema(
         gateway_api_url=gateway_api_url,
         registry_api_url=registry_api_url,
@@ -114,30 +119,32 @@ def _callback(
         storage_api_url=storage_api_url,
         profile_name=profile,
         config=config,
+        credential=credential,
         profile=user_profile,
     )
 
     ctx.obj = common_schema
 
 
-def _common(
-    ctx: typer.Context,
-) -> None:
-    """Inject required user_profile into context."""
-    user_profile = get_user_profile(ctx.obj.config, ctx.obj.profile_name)
-    ctx.obj.profile = user_profile
-
-
 app = typer.Typer(name="neosctl", callback=_callback)
 app.add_typer(profile.app, name="profile", help="Manage profiles.")
-app.add_typer(auth.app, name="auth", callback=_common, help="Manage authentication status.")
-app.add_typer(consume.app, name="consume", callback=_common, help="Consume published data products.")
-app.add_typer(iam.app, name="iam", callback=_common, help="Manage access policies.")
-app.add_typer(storage.app, name="storage", callback=_common, help="Interact with Storage (as a service).")
-app.add_typer(metadata.app, name="metadata", callback=_common, help="Manage and browse metadata.")
-app.add_typer(product.app, name="product", callback=_common, help="Manage data products.")
-app.add_typer(source.app, name="source", help="Manage sources.")
-app.add_typer(registry.app, name="registry", callback=_common, help="Manage cores and search data products.")
-app.add_typer(spark.app, name="spark", callback=_common, help="Manage data product spark jobs.")
-app.add_typer(secret.app, name="secret", callback=_common, help="Manage secrets.")
-app.add_typer(kafka.app, name="kafka", callback=_common, help="Manage data product kafka streaming.")
+app.add_typer(auth.app, name="auth", callback=user_profile_callback, help="Manage authentication status.")
+app.add_typer(services.iam.app, name="iam", callback=user_profile_callback, help="Manage access policies.")
+app.add_typer(
+    services.storage.app,
+    name="storage",
+    callback=user_profile_callback,
+    help="Interact with Storage (as a service).",
+)
+app.add_typer(
+    services.gateway.app,
+    name="gateway",
+    callback=user_profile_callback,
+    help="Interact with Gateway service.",
+)
+app.add_typer(
+    services.registry.app,
+    name="registry",
+    callback=user_profile_callback,
+    help="Manage cores and search data products.",
+)
