@@ -5,7 +5,14 @@ import click
 import typer
 
 from neosctl import schema, util
-from neosctl.util import exit_with_output, get_user_profile_section, prettify_json, remove_config, upsert_config
+from neosctl.util import (
+    exit_with_output,
+    get_user_profile_section,
+    prettify_json,
+    remove_config,
+    upsert_config,
+    upsert_credential,
+)
 
 app = typer.Typer()
 
@@ -32,6 +39,7 @@ def init(
     iam_api_url: typing.Optional[str] = typer.Option(None, "--iam-api-url", "-i", callback=util.sanitize),
     storage_api_url: typing.Optional[str] = typer.Option(None, "--storage-api-url", "-s", callback=util.sanitize),
     username: typing.Optional[str] = typer.Option(None, "--username", "-u", callback=util.sanitize),
+    account: typing.Optional[str] = typer.Option("root", "--account", "-a", callback=util.sanitize),
     ignore_tls: bool = typer.Option(
         False,
         "--ignore-tls",
@@ -52,6 +60,7 @@ def init(
     """
     typer.echo(f"Initialising [{ctx.obj.profile_name}] profile.")
     default_host = f"{hostname}/api/{{}}" if hostname else ""
+    bare_host = hostname.replace("http://", "").replace("https://", "") if hostname else ""
 
     if non_interactive and not (hostname and username):
         raise exit_with_output(
@@ -61,7 +70,7 @@ def init(
 
     if non_interactive:
         gateway_api_url = gateway_api_url or f"{hostname}/api/gateway"
-        storage_api_url = storage_api_url or f"{hostname}/api/storage"
+        storage_api_url = storage_api_url or f"https://saas.{bare_host}"
         iam_api_url = iam_api_url or f"{hostname}/api/iam"
         registry_api_url = registry_api_url or f"{hostname}/api/registry"
 
@@ -100,6 +109,7 @@ def init(
 
     profile = schema.Profile(  # nosec: B106
         user=username,
+        account=account,
         access_token="",
         refresh_token="",
         ignore_tls=ignore_tls,
@@ -125,10 +135,20 @@ def view(
     """View configuration for a profile."""
     profile = get_user_profile_section(ctx.obj.config, ctx.obj.profile_name)
     raise exit_with_output(
-        msg=prettify_json({k: v for k, v in profile.items()}),
+        msg=prettify_json({k: v for k, v in profile.items()}),  # noqa: C416
     )
 
 
+@app.command()
+def credentials(
+    ctx: typer.Context,
+    access_key_id: str,
+    secret_access_key: str,
+) -> None:
+    """View configuration for a profile."""
+    upsert_credential(ctx, access_key_id, secret_access_key)
+
+
 @app.command(name="list")
 def list_profiles(
     ctx: typer.Context,
